# liblineage

[![PyPi version](https://img.shields.io/pypi/v/liblineage)](https://pypi.org/project/liblineage/)

LineageOS utils library

Requires Python 3.8 or greater

## Installation

```sh
pip3 install liblineage
```

## Instructions

```sh
python3 -m liblineage
```

## License

```
#
# Copyright (C) 2022 The LineageOS Project
#
# SPDX-License-Identifier: LGPL-3.0-or-later
#
```
